import 'dart:convert';

import 'package:flutter/material.dart';

import '../../../models/statistics_global.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';
import 'statistics_global_content.dart';

class StatisticsGlobalCard extends StatelessWidget {
  const StatisticsGlobalCard({super.key});

  @override
  Widget build(BuildContext context) {
    late Future<StatisticsGlobalData> future = ScrobblesApi.fetchGlobalStatistics();

    return FutureBuilder<StatisticsGlobalData>(
      future: future,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return Card(
          elevation: 2,
          shadowColor: Theme.of(context).colorScheme.shadow,
          color: Theme.of(context).colorScheme.primary,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(8),
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: StatisticsGlobalContent(
              statistics: snapshot.hasData
                  ? StatisticsGlobalData.fromJson(jsonDecode(snapshot.data.toString()))
                  : StatisticsGlobalData.createEmpty(),
              isLoading: !snapshot.hasData,
            ),
          ),
        );
      },
    );
  }
}
